@@ -58,15 +58,15 @@ process_incremental_input(Incremental_binary*, unsigned int, Input_objects*,
 			  Task_token*, Task_token*);
 
 void
-gold_exit(bool status)
+gold_exit(Exit_status status)
 {
   if (parameters != NULL
       && parameters->options_valid()
       && parameters->options().has_plugins())
     parameters->options().plugins()->cleanup();
-  if (!status && parameters != NULL && parameters->options_valid())
+  if (status != GOLD_OK && parameters != NULL && parameters->options_valid())
     unlink_if_ordinary(parameters->options().output_file_name());
-  exit(status ? EXIT_SUCCESS : EXIT_FAILURE);
+  exit(status);
 }
 
 void
@@ -87,7 +87,7 @@ gold_nomem()
       const char* const s = ": out of memory\n";
       len = write(2, s, strlen(s));
     }
-  gold_exit(false);
+  gold_exit(GOLD_ERR);
 }
 
 // Handle an unreachable case.
@@ -97,7 +97,7 @@ do_gold_unreachable(const char* filename, int lineno, const char* function)
 {
   fprintf(stderr, _("%s: internal error in %s, at %s:%d\n"),
 	  program_name, function, filename, lineno);
-  gold_exit(false);
+  gold_exit(GOLD_ERR);
 }
 
 // This class arranges to run the functions done in the middle of the
@@ -176,7 +176,7 @@ queue_initial_tasks(const General_options& options,
   if (cmdline.begin() == cmdline.end())
     {
       if (options.printed_version())
-	gold_exit(true);
+	gold_exit(GOLD_OK);
       gold_fatal(_("no input files"));
     }
 
@@ -204,11 +204,7 @@ queue_initial_tasks(const General_options& options,
       if (parameters->incremental_update())
 	{
 	  Output_file* of = new Output_file(options.output_file_name());
-	  if (!of->open_for_modification())
-	    gold_info(_("incremental update not possible: "
-			"cannot open %s"),
-		      options.output_file_name());
-	  else
+	  if (of->open_base_file(options.incremental_base(), true))
 	    {
 	      ibase = open_incremental_binary(of);
 	      if (ibase != NULL
@@ -226,7 +222,7 @@ queue_initial_tasks(const General_options& options,
 	      if (set_parameters_incremental_full())
 		gold_info(_("linking with --incremental-full"));
 	      else
-		gold_fatal(_("restart link with --incremental-full"));
+		gold_fallback(_("restart link with --incremental-full"));
 	    }
 	}
     }
@@ -505,11 +501,7 @@ queue_middle_tasks(const General_options& options,
   if (parameters->options().gc_sections())
     {
       // Find the start symbol if any.
-      Symbol* start_sym;
-      if (parameters->options().entry())
-        start_sym = symtab->lookup(parameters->options().entry());
-      else
-        start_sym = symtab->lookup("_start");
+      Symbol* start_sym = symtab->lookup(parameters->entry());
       if (start_sym != NULL)
         {
           bool is_ordinary;
@@ -630,6 +622,15 @@ queue_middle_tasks(const General_options& options,
 	}
     }
 
+  // For incremental updates, record the existing GOT and PLT entries,
+  // and the COPY relocations.
+  if (parameters->incremental_update())
+    {
+      Incremental_binary* ibase = layout->incremental_base();
+      ibase->process_got_plt(symtab, layout);
+      ibase->emit_copy_relocs(symtab);
+    }
+
   if (is_debugging_enabled(DEBUG_SCRIPT))
     layout->script_options()->print(stderr);
 
@@ -747,7 +748,7 @@ queue_middle_tasks(const General_options& options,
 	  // THIS_BLOCKER to be NULL here.  There's no real point in
 	  // continuing if that happens.
 	  gold_assert(parameters->errors()->error_count() > 0);
-	  gold_exit(false);
+	  gold_exit(GOLD_ERR);
 	}
     }
 
